/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 */

#include <sal/config.h>

#include <prewin.h>
#include <postwin.h>

#include "demo/demo-atlas.cc"
#include "demo/demo-buffer.cc"
#include "demo/demo-font.cc"
#include "demo/demo-shader.cc"
#include "demo/matrix4x4.c"
